@@ -2,8 +2,8 @@ EvaluationMode <- function(value_s_1 = defineEvaluationModes()[2]) {
   self <- environment()
   class(self) <- append('EvaluationMode', class(self))
 
-  if (!value_s_1 %in% defineEvaluationModes()) abort('unauthorized value',
-                                                     strBracket(value_s_1))
+  if (!value_s_1 %in% defineEvaluationModes())
+    abort('unauthorized value', strBracket(value_s_1))
 
   is <- function(aValue_s_1) {
     aValue_s_1 == value_s_1
@@ -18,5 +18,5 @@ EvaluationMode <- function(value_s_1 = defineEvaluationModes()[2]) {
   self
 }
 
-print.EvaluationMode <- function(o) catn(o$toString())
+print.EvaluationMode <- function(x, ...) catn(x$toString(), ...)
 
